@@ -1,74 +1,69 @@
-/**********************************************************************
-This software program is available to you under a choice of one of two 
-licenses. You may choose to be licensed under either the GNU General Public 
-License (GPL) Version 2, June 1991, available at 
-http://www.fsf.org/copyleft/gpl.html, or the Intel BSD + Patent License, the 
-text of which follows:
+/*******************************************************************************
 
-Recipient has requested a license and Intel Corporation ("Intel") is willing
-to grant a license for the software entitled Linux Base Driver for the 
-Intel(R) PRO/100 Family of Adapters (e100) (the "Software") being provided 
-by Intel Corporation. The following definitions apply to this license:
+  Recipient has requested a license and Intel Corporation ("Intel") is
+  willing to grant a license for the software entitled Linux Base Driver
+  for the Intel(R) PRO/1000 Familty of Adapters (e1000) (the "Software")
+  being provided by Intel Corporation.
+  
+  The following definitions apply to this License:
+  
+  "Licensed Patents" means patent claims licensable by Intel Corporation
+  which are necessarily infringed by the use or sale of the Software alone
+  or when combined with the operating system referred to below.
+  "Recipient" means the party to whom Intel delivers this Software.
+  "Licensee" means Recipient and those third parties that receive a license
+  to any operating system available under the GNU Public License version
+  2.0 or later.
+  
+  Copyright (c) 1999-2001 Intel Corporation All rights reserved.
+  
+  The license is provided to Recipient and Recipient's Licensees under
+  the following terms.
+  
+  Redistribution and use in source and binary forms of the Software,
+  with or without modification, are permitted provided that the following
+  conditions are met:
+  
+  Redistributions of source code of the Software may retain the above
+  copyright notice, this list of conditions and the following disclaimer.
+  Redistributions in binary form of the Software may reproduce the above
+  copyright notice, this list of conditions and the following disclaimer in
+  the documentation and/or other materials provided with the distribution.
+  Neither the name of Intel Corporation nor the names of its contributors
+  shall be used to endorse or promote products derived from this Software
+  without specific prior written permission.
+  
+  Intel hereby grants Recipient and Licensees a non-exclusive, worldwide,
+  royalty-free patent license under Licensed Patents to make, use, sell,
+  offer to sell, import and otherwise transfer the Software, if any, in
+  source code and object code form. This license shall include changes
+  to the Software that are error corrections or other minor changes
+  to the Software that do not add functionality or features when the
+  Software is incorporated in any version of a operating system that has
+  been distributed under the GNU General Public License 2.0 or later.
+  This patent license shall apply to the combination of the Software and
+  any operating system licensed under the GNU Public License version 2.0
+  or later if, at the time Intel provides the Software to Recipient, such
+  addition of the Software to the then publicly available versions of such
+  operating system available under the GNU Public License version 2.0 or
+  later (whether in gold, beta or alpha form) causes such combination to
+  be covered by the Licensed Patents. The patent license shall not apply
+  to any other combinations which include the Software. No hardware per
+  se is licensed hereunder.
+  
+  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
+  IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
+  THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+  PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL INTEL OR ITS CONTRIBUTORS
+  BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
+  OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+  SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+  INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+  CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+  THE POSSIBILITY OF SUCH DAMAGE.
 
-"Licensed Patents" means patent claims licensable by Intel Corporation which 
-are necessarily infringed by the use of sale of the Software alone or when 
-combined with the operating system referred to below.
-
-"Recipient" means the party to whom Intel delivers this Software.
-
-"Licensee" means Recipient and those third parties that receive a license to 
-any operating system available under the GNU Public License version 2.0 or 
-later.
-
-Copyright (c) 1999 - 2002 Intel Corporation.
-All rights reserved.
-
-The license is provided to Recipient and Recipient's Licensees under the 
-following terms.
-
-Redistribution and use in source and binary forms of the Software, with or 
-without modification, are permitted provided that the following conditions 
-are met:
-
-Redistributions of source code of the Software may retain the above 
-copyright notice, this list of conditions and the following disclaimer.
-
-Redistributions in binary form of the Software may reproduce the above 
-copyright notice, this list of conditions and the following disclaimer in 
-the documentation and/or materials provided with the distribution.
-
-Neither the name of Intel Corporation nor the names of its contributors 
-shall be used to endorse or promote products derived from this Software 
-without specific prior written permission.
-
-Intel hereby grants Recipient and Licensees a non-exclusive, worldwide, 
-royalty-free patent license under Licensed Patents to make, use, sell, offer 
-to sell, import and otherwise transfer the Software, if any, in source code 
-and object code form. This license shall include changes to the Software 
-that are error corrections or other minor changes to the Software that do 
-not add functionality or features when the Software is incorporated in any 
-version of an operating system that has been distributed under the GNU 
-General Public License 2.0 or later. This patent license shall apply to the 
-combination of the Software and any operating system licensed under the GNU 
-Public License version 2.0 or later if, at the time Intel provides the 
-Software to Recipient, such addition of the Software to the then publicly 
-available versions of such operating systems available under the GNU Public 
-License version 2.0 or later (whether in gold, beta or alpha form) causes 
-such combination to be covered by the Licensed Patents. The patent license 
-shall not apply to any other combinations which include the Software. NO 
-hardware per se is licensed hereunder.
-
-THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
-AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
-IMPLIED WARRANTIES OF MECHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
-ARE DISCLAIMED. IN NO EVENT SHALL INTEL OR IT CONTRIBUTORS BE LIABLE FOR ANY 
-DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES 
-(INCLUDING, BUT NOT LIMITED, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
-ANY LOSS OF USE; DATA, OR PROFITS; OR BUSINESS INTERUPTION) HOWEVER CAUSED 
-AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY OR 
-TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
-OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-**********************************************************************/
+*******************************************************************************/
 
 /**********************************************************************
 *                                                                     *
@@ -92,7 +87,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 /* I meant to make these inline, but don't have time to figure out
 ** compiler problems right now...
 */
-BD_ANS_BOOLEAN BD_ANS_BCMP(UCHAR *s1, UCHAR *s2, UINT32 length)
+BD_ANS_BOOLEAN BD_ANS_BCMP(u8 *s1, u8 *s2, u32 length)
 {
     while (length) {
         if (*s1 != *s2)
@@ -104,7 +99,7 @@ BD_ANS_BOOLEAN BD_ANS_BCMP(UCHAR *s1, UCHAR *s2, UINT32 length)
  
  
  
-VOID BD_ANS_BCOPY(UCHAR *destination, UCHAR *source, UINT32 length) 
+void BD_ANS_BCOPY(u8 *destination, u8 *source, u32 length)
 {
     while (length--) {
         *destination++ = *source++;
@@ -112,7 +107,7 @@ VOID BD_ANS_BCOPY(UCHAR *destination, UCHAR *source, UINT32 length)
 }
  
  
-VOID BD_ANS_BZERO(UCHAR *s, UINT32 length)
+void BD_ANS_BZERO(u8 *s, u32 length)
 {
     while (length--)
         *s++ = 0;
@@ -146,8 +141,8 @@ BD_ANS_STATUS bd_ans_ProcessRequest(BOARD_PRIVATE_STRUCT *bps,
     /* Only allow IANS_OP_BD_IDENTIFY if iANS comm is down */
     if((iANSdata->iANS_status == IANS_COMMUNICATION_DOWN) && 
        (header->Opcode!=IANS_OP_BD_IDENTIFY)) {
-        DEBUGLOG("bd_ans_ProcessRequest: ANS communication not up\n");
-        return BD_ANS_FAILURE;
+      DEBUGLOG("bd_ans_ProcessRequest: ANS communication not up\n");
+      return BD_ANS_FAILURE;
     }
     
     switch (header->Opcode) {
@@ -220,7 +215,7 @@ BD_ANS_STATUS bd_ans_Identify(BOARD_PRIVATE_STRUCT *bps,
 
 {
     IANS_BD_PARAM_IDENTIFY *iANSidentify;
-    UINT32 BDCommVersion;               /* base driver communication version */
+    u32 BDCommVersion;               /* base driver communication version */
 
     /* Get our comm version from the #defines */
     BDCommVersion = (IANS_BD_COMM_VERSION_MAJOR << 16) +  IANS_BD_COMM_VERSION_MINOR;
@@ -229,9 +224,9 @@ BD_ANS_STATUS bd_ans_Identify(BOARD_PRIVATE_STRUCT *bps,
     /* if copyright string doesnt match or iANS comm version is older return error */
     if ((iANSidentify->iANSCommVersion < BDCommVersion)||
         (BD_ANS_BCMP(iANSidentify->iANSSignature,
-                     (UCHAR *)IntelCopyrightString,
+                     (u8 *)IntelCopyrightString,
                      IANS_SIGNATURE_LENGTH)) != BD_ANS_TRUE) {
-        return BD_ANS_FAILURE;
+            return BD_ANS_FAILURE;
     }
    
     BD_ANS_DRV_LOCK;
@@ -240,7 +235,7 @@ BD_ANS_STATUS bd_ans_Identify(BOARD_PRIVATE_STRUCT *bps,
     iANSdata->iANS_status = IANS_COMMUNICATION_UP;
     iANSidentify->BDCommVersion = BDCommVersion;
     BD_ANS_BCOPY(iANSidentify->BDSignature,
-                 (UCHAR *)IntelCopyrightString,
+                 (u8 *)IntelCopyrightString,
                  IANS_SIGNATURE_LENGTH);
 
     
@@ -266,7 +261,7 @@ BD_ANS_STATUS bd_ans_Identify(BOARD_PRIVATE_STRUCT *bps,
 **
 **  Returns:    void
 */
-VOID
+void
 bd_ans_Init(iANSsupport_t *iANSdata)
 {
     /* set all the communication flags to initial values */
@@ -308,7 +303,7 @@ BD_ANS_STATUS bd_ans_Disconnect(BOARD_PRIVATE_STRUCT *bps,
     if (iANSdata->reporting_mode == IANS_STATUS_REPORTING_ON)
         bd_ans_DeActivateFastPolling(bps, iANSdata);
 
-    BD_ANS_DRV_UNLOCK;
+        BD_ANS_DRV_UNLOCK;
 
     return (bd_ans_ResetAllModes(bps, iANSdata));
 }
@@ -368,7 +363,7 @@ BD_ANS_STATUS bd_ans_ExtendedGetCapability(BOARD_PRIVATE_STRUCT *bps,
 **                               successfully, FAILURE otherwise.
 */
 BD_ANS_STATUS bd_ans_ExtendedSetMode(BOARD_PRIVATE_STRUCT *bps,
-                                     iANSsupport_t *iANSdata,
+                                     iANSsupport_t *iANSdata,                                     
                                      IANS_BD_PARAM_HEADER *header)
 {
     BD_ANS_STATUS status;
@@ -381,9 +376,9 @@ BD_ANS_STATUS bd_ans_ExtendedSetMode(BOARD_PRIVATE_STRUCT *bps,
 
     /* see if we are being configured to tx/rx tlv */
     if (request->BDIansAttributedMode == IANS_REQUEST_SUPPORT)
-        iANSdata->attributed_mode = (UINT32) BD_ANS_TRUE;
+        iANSdata->attributed_mode = (u32) BD_ANS_TRUE;
     else
-        iANSdata->attributed_mode = (UINT32) BD_ANS_FALSE;
+        iANSdata->attributed_mode = (u32) BD_ANS_FALSE;
 
     /* see if we are being requested to send packets to the
      * ANS protocol
@@ -478,8 +473,6 @@ BD_ANS_STATUS bd_ans_TagGetCapability(BOARD_PRIVATE_STRUCT *bps,
      * initialized by GetAllCapabilities during the Identify 
      * request.
      */
-    ((IANS_BD_PARAM_ITAG_CAP *)header)->ISLTagMode = 
-        ANS_BD_SUPPORTS(iANSdata->ISL_tag_support);
     ((IANS_BD_PARAM_ITAG_CAP *)header)->IEEE802_3acTagMode = 
         ANS_BD_SUPPORTS(iANSdata->IEEE_tag_support);
     
@@ -510,12 +503,6 @@ BD_ANS_STATUS bd_ans_TagSetMode(BOARD_PRIVATE_STRUCT *bps,
 
     /* filter off requests for unsupported modes */ 
     switch(((IANS_BD_PARAM_ITAG_SET_MODE *)header)->SetTagMode){
-    case IANS_BD_TAGGING_ISL:
-        DEBUGLOG("bd_ans_TagSetMode: ISL support requested\n");
-        if (iANSdata->ISL_tag_support == BD_ANS_FALSE)
-            return BD_ANS_FAILURE;
-        break;
-        
     case IANS_BD_TAGGING_802_3AC:
         DEBUGLOG("bd_ans_TagSetMode: IEEE support requested\n");
         if (iANSdata->IEEE_tag_support == BD_ANS_FALSE)
@@ -603,7 +590,7 @@ BD_ANS_STATUS bd_ans_VlanSetMode(BOARD_PRIVATE_STRUCT *bps,
 {
     int i;
     IANS_BD_PARAM_IVLAN_SET_MODE *request = 
-        (IANS_BD_PARAM_IVLAN_SET_MODE *)header;
+      (IANS_BD_PARAM_IVLAN_SET_MODE *)header;
 
     DEBUGLOG("bd_ans_VlanSetMode: enter\n");
 
@@ -676,18 +663,18 @@ BD_ANS_STATUS bd_ans_VlanSetTable(BOARD_PRIVATE_STRUCT *bps,
      * vlan filtering.  This was set in VlanSetMode.
      */
     if (iANSdata->vlan_filtering_mode == IANS_VLAN_FILTERING_ON) {
-        /* this function assumes that ANS sends us a complete 
-         * table - so we blow away the old one
-         */
-        iANSdata->num_vlan_filter = request->VLanIDNum;
-        for (i = 0; i < iANSdata->num_vlan_filter; i++) {
-            iANSdata->VlanID[i] = request->VLanIDTable[i];
-        }
-        /* let the driver call the hardware routine to configure
-         * the vlan table.
-         */
-        bd_ans_drv_ConfigureVlanTable(bps); 
-        return BD_ANS_SUCCESS;
+      /* this function assumes that ANS sends us a complete 
+       * table - so we blow away the old one
+       */
+      iANSdata->num_vlan_filter = request->VLanIDNum;
+      for (i = 0; i < iANSdata->num_vlan_filter; i++) {
+          iANSdata->VlanID[i] = request->VLanIDTable[i];
+      }
+      /* let the driver call the hardware routine to configure
+       * the vlan table.
+       */
+      bd_ans_drv_ConfigureVlanTable(bps); 
+      return BD_ANS_SUCCESS; 
     }
     return BD_ANS_FAILURE;
 }                              
@@ -742,8 +729,8 @@ BD_ANS_STATUS bd_ans_DeActivateFastPolling(BOARD_PRIVATE_STRUCT *bps,
      * a watchdog routine going.
      */
     if (iANSdata->timer_id) {
-        bd_ans_drv_StopWatchdog(bps);
-        iANSdata->timer_id = 0;
+       bd_ans_drv_StopWatchdog(bps);
+       iANSdata->timer_id = 0;
     }    
     return (BD_ANS_SUCCESS);
 }
@@ -768,7 +755,7 @@ BD_ANS_STATUS bd_ans_DeActivateFastPolling(BOARD_PRIVATE_STRUCT *bps,
 */
 BD_ANS_STATUS bd_ans_SetReportingMode(BOARD_PRIVATE_STRUCT *bps, 
                                       iANSsupport_t *iANSdata,
-                                      VOID *ans_buffer)
+                                      void *ans_buffer)
 {
     BD_ANS_STATUS status;
     IANS_BD_PARAM_EXT_SET_MODE *iANSreport;
@@ -807,38 +794,38 @@ BD_ANS_STATUS bd_ans_SetReportingMode(BOARD_PRIVATE_STRUCT *bps,
 */                                      
 BD_ANS_STATUS bd_ans_FillStatus(BOARD_PRIVATE_STRUCT *bps,
                                 iANSsupport_t *iANSdata,
-                                VOID *ans_buffer)
+                                void *ans_buffer)
 {
     IANS_BD_PARAM_STATUS *iANSstatus = (IANS_BD_PARAM_STATUS *)ans_buffer;
 
     DEBUGLOG("bd_ans_FillStatus: enter\n");
 
     /* tell iANS the supported version of this structure */
-    iANSstatus->StatusVersion = IANS_STATUS_VERSION;
+    iANSstatus->StatusVersion       = IANS_STATUS_VERSION;
 
     /* all these support fields are initialized during the Identify request */
     /* check for link status */ 
-    if (iANSdata->status_support_flags & BD_ANS_LINK_STATUS_SUPPORTED) {
-        iANSstatus->LinkStatus  = *(iANSdata->link_status);
-
+    if (iANSdata->status_support_flags & BD_ANS_LINK_STATUS_SUPPORTED) {    
+        iANSstatus->LinkStatus = *(iANSdata->link_status);
+     
         if (iANSstatus->LinkStatus == IANS_STATUS_LINK_FAIL) {
             iANSstatus->LinkSpeed = IANS_STATUS_LINK_SPEED_NOT_SUPPORTED;
             iANSstatus->Duplex = IANS_STATUS_DUPLEX_NOT_SUPPORTED;
         } else {
             if (iANSdata->status_support_flags & BD_ANS_SPEED_STATUS_SUPPORTED) {
                 switch(*(iANSdata->line_speed)) {
-                case BD_ANS_10_MBPS:
-                    iANSstatus->LinkSpeed = IANS_STATUS_LINK_SPEED_10MBPS;
-                    break;
-                case BD_ANS_100_MBPS:
-                    iANSstatus->LinkSpeed = IANS_STATUS_LINK_SPEED_100MBPS;
-                    break;
-                case BD_ANS_1000_MBPS:
-                    iANSstatus->LinkSpeed = IANS_STATUS_LINK_SPEED_1000MBPS;
-                    break;
-                default:
-                    iANSstatus->LinkSpeed = IANS_STATUS_LINK_SPEED_NOT_SUPPORTED;
-                    break;
+                    case BD_ANS_10_MBPS:
+                        iANSstatus->LinkSpeed = IANS_STATUS_LINK_SPEED_10MBPS;
+                        break;
+                    case BD_ANS_100_MBPS:
+                        iANSstatus->LinkSpeed = IANS_STATUS_LINK_SPEED_100MBPS;
+                        break;
+                    case BD_ANS_1000_MBPS:
+                        iANSstatus->LinkSpeed = IANS_STATUS_LINK_SPEED_1000MBPS;
+                        break;
+                    default:
+                        iANSstatus->LinkSpeed = IANS_STATUS_LINK_SPEED_NOT_SUPPORTED;
+                        break;
                 }
             } else {
                 iANSstatus->LinkSpeed = IANS_STATUS_LINK_SPEED_NOT_SUPPORTED;
@@ -847,15 +834,15 @@ BD_ANS_STATUS bd_ans_FillStatus(BOARD_PRIVATE_STRUCT *bps,
             /* check for duplex status */   
             if (iANSdata->status_support_flags & BD_ANS_DUPLEX_STATUS_SUPPORTED) {          
                 switch (*(iANSdata->duplex)) {
-                case BD_ANS_DUPLEX_FULL:
-                    iANSstatus->Duplex = IANS_STATUS_DUPLEX_FULL;
-                    break;
-                case BD_ANS_DUPLEX_HALF:
-                    iANSstatus->Duplex = IANS_STATUS_DUPLEX_HALF;
-                    break;
-                default:
-                    iANSstatus->Duplex = IANS_STATUS_DUPLEX_NOT_SUPPORTED;
-                    break;
+                    case BD_ANS_DUPLEX_FULL:
+                        iANSstatus->Duplex = IANS_STATUS_DUPLEX_FULL;
+                        break;
+                    case BD_ANS_DUPLEX_HALF:
+                        iANSstatus->Duplex = IANS_STATUS_DUPLEX_HALF;
+                        break;
+                    default:
+                        iANSstatus->Duplex = IANS_STATUS_DUPLEX_NOT_SUPPORTED;
+                        break;
                 }
             } else {
                 iANSstatus->Duplex = IANS_STATUS_DUPLEX_NOT_SUPPORTED;
@@ -918,11 +905,11 @@ BD_ANS_STATUS bd_ans_ResetAllModes(BOARD_PRIVATE_STRUCT *bps,
      * much I can do about it if it fails 
      */
     (void)bd_ans_DeActivateFastPolling(bps, iANSdata);
-    BD_ANS_BZERO((UCHAR *)&iANSdata->prev_status,sizeof(IANS_BD_PARAM_STATUS));
+    BD_ANS_BZERO((u8 *)&iANSdata->prev_status,sizeof(IANS_BD_PARAM_STATUS));
     
     /* set link to iANS as down  */
     iANSdata->iANS_status          = IANS_COMMUNICATION_DOWN;
-    iANSdata->attributed_mode      = (UINT32) BD_ANS_FALSE;
+    iANSdata->attributed_mode      = (u32) BD_ANS_FALSE;
     iANSdata->routing_mode         = IANS_ROUTING_OFF;
     
 #ifdef IANS_BASE_VLAN_TAGGING
@@ -931,17 +918,17 @@ BD_ANS_STATUS bd_ans_ResetAllModes(BOARD_PRIVATE_STRUCT *bps,
     (void) bd_ans_drv_ConfigureTagging(bps);
     
     /* need to reconfigure the adapter to disable vlan mode */    
-    iANSdata->vlan_mode = IANS_VLAN_MODE_OFF;
+    iANSdata->vlan_mode            = IANS_VLAN_MODE_OFF;
     (void) bd_ans_drv_ConfigureVlan(bps);
     
     /* need to reset the vlan filter table and configure the
      * adapter to disable vlan filtering 
      */
     iANSdata->vlan_filtering_mode = IANS_VLAN_FILTERING_OFF;
-    iANSdata->num_vlan_filter = 0;
+        iANSdata->num_vlan_filter      = 0;
     for (i = 0; i < MAX_NUM_VLAN; i++) {
-        iANSdata->VlanID[i] = 0;
-    }
+                iANSdata->VlanID[i] = 0;
+        }
     (void) bd_ans_drv_ConfigureVlanTable(bps);
 #endif
 
@@ -976,7 +963,6 @@ BD_ANS_STATUS bd_ans_GetAllCapabilities(BOARD_PRIVATE_STRUCT *bps,
     iANSdata->status_support_flags = BD_ANS_DRV_STATUS_SUPPORT_FLAGS;
     iANSdata->max_vlan_ID_supported = BD_ANS_DRV_MAX_VLAN_ID(bps);
     iANSdata->vlan_table_size = BD_ANS_DRV_MAX_VLAN_TABLE_SIZE(bps);
-    iANSdata->ISL_tag_support = BD_ANS_DRV_ISL_TAG_SUPPORT(bps);
     iANSdata->IEEE_tag_support = BD_ANS_DRV_IEEE_TAG_SUPPORT(bps);
     iANSdata->vlan_support =   BD_ANS_DRV_VLAN_SUPPORT(bps);
     iANSdata->vlan_filtering_support = BD_ANS_DRV_VLAN_FILTER_SUPPORT(bps);
@@ -1005,7 +991,7 @@ BD_ANS_STATUS bd_ans_GetAllCapabilities(BOARD_PRIVATE_STRUCT *bps,
 **              OS_DATA **os_tlv - pointer to a pointer to the os structure
 **                                 containing the tlv data.  This pointer is
 **                                 modified by this routine.
-**              UINT32 *tlv_list_length - pointer to the length of the
+**              u32 *tlv_list_length - pointer to the length of the
 **                                      new tlv list.  This is modified
 **                                      by this routine.  It is provided in 
 **                                      case some OS needs to adjust the
@@ -1020,12 +1006,12 @@ BD_ANS_STATUS bd_ans_Receive(BOARD_PRIVATE_STRUCT *bps,
                              FRAME_DATA *frame,
                              OS_DATA *os_frame_data,
                              OS_DATA **os_tlv,
-                             UINT32 *tlv_list_length)
+                             u32 *tlv_list_length)
 {
     BD_ANS_BOOLEAN Frame_is_tagged;
     peth_vlan_header_t peth_vlan_header =  (peth_vlan_header_t )frame;
-    UINT16 tag;
-    UINT32 tlvlist_length = 0; /* Total length of all TLVs */
+    u16 tag;
+    u32 tlvlist_length = 0; /* Total length of all TLVs */
 
     DEBUGLOG("bd_ans_Receive: enter\n");
 
@@ -1051,13 +1037,13 @@ BD_ANS_STATUS bd_ans_Receive(BOARD_PRIVATE_STRUCT *bps,
              */
             DEBUGLOG("bd_ans_Receive: Tagging mode NONE\n");
             if (Frame_is_tagged) {
-                if (tag) {
-                    DEBUGLOG("bd_ans_Receive: Invalid VLAN packet\n");
-                    return BD_ANS_FAILURE;
-                }
-                /* priority tagged */
-                if (iANSdata->vlan_offload_support == BD_ANS_FALSE)
-                    bd_ans_os_StripQtagSW(os_frame_data);
+              if (tag) {
+                  DEBUGLOG("bd_ans_Receive: Invalid VLAN packet\n");
+                  return BD_ANS_FAILURE;
+              }
+              /* priority tagged */
+              if (iANSdata->vlan_offload_support == BD_ANS_FALSE)
+                  bd_ans_os_StripQtagSW(os_frame_data);
             }
             break;
             
@@ -1078,41 +1064,41 @@ BD_ANS_STATUS bd_ans_Receive(BOARD_PRIVATE_STRUCT *bps,
                 return BD_ANS_FAILURE;
             }
             if (tlvlist_length == 0) {
-                if (bd_ans_os_AllocateTLV(os_frame_data, os_tlv) == BD_ANS_FAILURE) {
-                    DEBUGLOG("bd_ans_Receive: Failed to allocated TLV\n");
-                    return BD_ANS_FAILURE;
-                }
+              if (bd_ans_os_AllocateTLV(os_frame_data, os_tlv) == BD_ANS_FAILURE) {
+                  DEBUGLOG("bd_ans_Receive: Failed to allocated TLV\n");
+                  return BD_ANS_FAILURE;
+              }
             }
             if (Frame_is_tagged) {
-                /* VLAN_ID TLV */
-                tlvlist_length += bd_ans_os_AttributeFill(IANS_ATTR_VLAN_ID, 
-                                                          *os_tlv, 
-                                                          tlvlist_length,
-                                                          (void *)&tag);
-                if (iANSdata->vlan_offload_support == BD_ANS_FALSE)
-                    bd_ans_os_StripQtagSW(os_frame_data);
-            } else {
-                /* Send along, but untagged */
-                /* Untagged TLV */
-                tlvlist_length += 
-                    bd_ans_os_AttributeFill(IANS_ATTR_TAGGING_UNTAGGED, 
-                                            *os_tlv, 
-                                            tlvlist_length,
-                                            NULL);
+              /* VLAN_ID TLV */
+              tlvlist_length += bd_ans_os_AttributeFill(IANS_ATTR_VLAN_ID, 
+                                                        *os_tlv, 
+                                                        tlvlist_length,
+                                                        (void *)&tag);
+              if (iANSdata->vlan_offload_support == BD_ANS_FALSE)
+                  bd_ans_os_StripQtagSW(os_frame_data);
+            } 
+            else {
+              /* Send along, but untagged */
+              /* Untagged TLV */
+              tlvlist_length += bd_ans_os_AttributeFill(IANS_ATTR_TAGGING_UNTAGGED, 
+                                                        *os_tlv, 
+                                                        tlvlist_length,
+                                                        NULL);
             }
             break;
-        default:
-            DEBUGLOG("bd_ans_Receive: Invalid tagging mode\n");
-            return BD_ANS_FAILURE;        
+    default:     
+      DEBUGLOG("bd_ans_Receive: Invalid tagging mode\n");
+      return BD_ANS_FAILURE;        
     }
 #endif
     /* allocate space for the last attribute TLV */
     if (tlvlist_length == 0) {
-        if (bd_ans_os_AllocateTLV(os_frame_data, os_tlv) ==
-            BD_ANS_FAILURE) {
-            DEBUGLOG("bd_ans_Receive: failed to allocated TLV\n");
-            return BD_ANS_FAILURE;                 
-        }
+      if (bd_ans_os_AllocateTLV(os_frame_data, os_tlv) ==
+          BD_ANS_FAILURE) {
+          DEBUGLOG("bd_ans_Receive: failed to allocated TLV\n");
+          return BD_ANS_FAILURE;                 
+      }
     }       
     
     /* Last Attribute TLV */
@@ -1150,12 +1136,12 @@ BD_ANS_STATUS bd_ans_Transmit(BOARD_PRIVATE_STRUCT *bps,
                               pPer_Frame_Attribute_Header pTLV,
                               HW_TX_DESCRIPTOR *txd,
                               OS_DATA **frame_ptr,
-                              UINT16 *vlanid)
+                              u16 *vlanid)
 {
     DEBUGLOG("bd_ans_Transmit: enter\n");
  
 #ifdef IANS_BASE_VLAN_TAGGING
-    *vlanid = INVALID_VLAN_ID;
+   *vlanid = INVALID_VLAN_ID;
    
     /* if we are not in tagging mode, we have nothing to do */
     if ( iANSdata->tag_mode == IANS_BD_TAGGING_NONE ) {
@@ -1163,34 +1149,35 @@ BD_ANS_STATUS bd_ans_Transmit(BOARD_PRIVATE_STRUCT *bps,
     }
     /* traverse the list of TLVs until we get to the Last TLV. */
     while (pTLV->AttributeID != IANS_ATTR_LAST_ATTR) { 
-        switch( pTLV->AttributeID ) {
-        case IANS_ATTR_VLAN_ID:
-            *vlanid = (UINT16) bd_ans_ExtractValue(pTLV);
-            break;
-        default:
-            break;
-        } /* switch AttributeID */
-        
-        pTLV = GET_NEXT_TLV(pTLV);
+      switch( pTLV->AttributeID ) {
+      case IANS_ATTR_VLAN_ID:
+        *vlanid = (u16) bd_ans_ExtractValue(pTLV);
+        break;
+      default:
+        break;
+      } /* switch AttributeID */
+
+      pTLV = GET_NEXT_TLV(pTLV);
     }
 
     DEBUGLOG1("bd_ans_Transmit: vlanid=%d\n", *vlanid);
     if (*vlanid != INVALID_VLAN_ID) {
-        /* we can insert the qtag here.  Doing this here instead of
-         * within the while loop insures that the TLV list is no longer
-         * needed, and we can recycle that extra memory (if needed)
-         */
-        if (iANSdata->vlan_offload_support == BD_ANS_FALSE) {
-            if (bd_ans_os_InsertQtagSW(bps, frame_ptr, vlanid) == BD_ANS_FAILURE) { 
-                DEBUGLOG("bd_ans_Transmit: Failed to insert qtag sw\n");
-                return BD_ANS_FAILURE; 
-            }              
-        } else {
-            if (bd_ans_hw_InsertQtagHW(bps, txd, vlanid) == BD_ANS_FAILURE) { 
-                DEBUGLOG("bd_ans_Transmit: Failed to insert qtag hw\n");
-                return BD_ANS_FAILURE;
-            }
+      /* we can insert the qtag here.  Doing this here instead of
+       * within the while loop insures that the TLV list is no longer
+       * needed, and we can recycle that extra memory (if needed)
+       */
+      if (iANSdata->vlan_offload_support == BD_ANS_FALSE) {
+        if (bd_ans_os_InsertQtagSW(bps, frame_ptr, vlanid) == BD_ANS_FAILURE) { 
+            DEBUGLOG("bd_ans_Transmit: Failed to insert qtag sw\n");
+            return BD_ANS_FAILURE; 
+        }              
+      }
+      else {
+        if (bd_ans_hw_InsertQtagHW(bps, txd, vlanid) == BD_ANS_FAILURE) { 
+            DEBUGLOG("bd_ans_Transmit: Failed to insert qtag hw\n");
+            return BD_ANS_FAILURE;
         }
+      }
     }
 #endif
     return (BD_ANS_SUCCESS);
@@ -1256,9 +1243,9 @@ bd_ans_IsQtagPacket(BOARD_PRIVATE_STRUCT *bps,
 **                                          rx frame descriptor
 **              eth_vlan_header_t *header - pointer to the actual frame data
 **
-**  Returns:    UINT16      - the IEEE vlan id.
+**  Returns:    u16      - the IEEE vlan id.
 */
-UINT16
+u16
 bd_ans_GetVlanId(BOARD_PRIVATE_STRUCT *bps,
                  iANSsupport_t *iANSdata, 
                  HW_RX_DESCRIPTOR *rxd,
@@ -1283,9 +1270,9 @@ bd_ans_GetVlanId(BOARD_PRIVATE_STRUCT *bps,
 **               void *data                - optional data to be added to the
 **                                           TLV (the V part)
 **
-** Returns:      UINT32                    - the length of the new TLV
+** Returns:      u32                    - the length of the new TLV
 */
-UINT32
+u32
 bd_ans_AttributeFill(iANS_Attribute_ID attr_id, 
                      void *pTLV, 
                      void *data)
@@ -1308,8 +1295,8 @@ bd_ans_AttributeFill(iANS_Attribute_ID attr_id,
         vlan_pfi = (VLAN_ID_Per_Frame_Info *)pTLV;
         vlan_pfi->AttrHeader.AttributeID = IANS_ATTR_VLAN_ID;
         vlan_pfi->AttrHeader.AttributeLength = 
-            tlv_length - sizeof(Per_Frame_Attribute_Header);
-        vlan_pfi->VLanID = *((UINT16 *)data);
+          tlv_length - sizeof(Per_Frame_Attribute_Header);
+        vlan_pfi->VLanID = *((u16 *)data);
         break;
       
     case IANS_ATTR_TAGGING_UNTAGGED: 
@@ -1318,7 +1305,7 @@ bd_ans_AttributeFill(iANS_Attribute_ID attr_id,
         untagged = (Untagged_Attribute *)pTLV;
         untagged->AttrHeader.AttributeID = IANS_ATTR_TAGGING_UNTAGGED;
         untagged->AttrHeader.AttributeLength = 
-            tlv_length - sizeof(Per_Frame_Attribute_Header);
+          tlv_length - sizeof(Per_Frame_Attribute_Header);
         break;
 #endif            
     case IANS_ATTR_LAST_ATTR:
@@ -1330,7 +1317,7 @@ bd_ans_AttributeFill(iANS_Attribute_ID attr_id,
         break;
 
     default:
-        break;
+	break;
     }
     return tlv_length;
 }    
@@ -1344,16 +1331,16 @@ bd_ans_AttributeFill(iANS_Attribute_ID attr_id,
 **
 **  Arguments:  Per_Frame_Attribute_Header *pTLV - pointer to the TLV
 **
-**  Returns:    UINT32 - dword value from the TLV.  Smaller values 
+**  Returns:    u32 - dword value from the TLV.  Smaller values
 **                       should be cast correctly by the caller.
 */
-UINT32
+u32
 bd_ans_ExtractValue(Per_Frame_Attribute_Header *pTLV)
 {
-    UINT32 ret_val;
-    UCHAR *p;
-    p = (UCHAR *) &(pTLV->AttributeLength);
+    u32 ret_val;
+    u8 *p;
+    p = (u8 *) &(pTLV->AttributeLength);
     p += sizeof(pTLV->AttributeLength);
-    ret_val = *((UINT32 *)p);
+    ret_val = *((u32 *)p);
     return (ret_val); 
 }                     
