@@ -1,74 +1,69 @@
-/**********************************************************************
-This software program is available to you under a choice of one of two 
-licenses. You may choose to be licensed under either the GNU General Public 
-License (GPL) Version 2, June 1991, available at 
-http://www.fsf.org/copyleft/gpl.html, or the Intel BSD + Patent License, the 
-text of which follows:
+/*******************************************************************************
 
-Recipient has requested a license and Intel Corporation ("Intel") is willing
-to grant a license for the software entitled Linux Base Driver for the 
-Intel(R) PRO/100 Family of Adapters (e100) (the "Software") being provided 
-by Intel Corporation. The following definitions apply to this license:
+  Recipient has requested a license and Intel Corporation ("Intel") is
+  willing to grant a license for the software entitled Linux Base Driver
+  for the Intel(R) PRO/1000 Familty of Adapters (e1000) (the "Software")
+  being provided by Intel Corporation.
+  
+  The following definitions apply to this License:
+  
+  "Licensed Patents" means patent claims licensable by Intel Corporation
+  which are necessarily infringed by the use or sale of the Software alone
+  or when combined with the operating system referred to below.
+  "Recipient" means the party to whom Intel delivers this Software.
+  "Licensee" means Recipient and those third parties that receive a license
+  to any operating system available under the GNU Public License version
+  2.0 or later.
+  
+  Copyright (c) 1999-2001 Intel Corporation All rights reserved.
+  
+  The license is provided to Recipient and Recipient's Licensees under
+  the following terms.
+  
+  Redistribution and use in source and binary forms of the Software,
+  with or without modification, are permitted provided that the following
+  conditions are met:
+  
+  Redistributions of source code of the Software may retain the above
+  copyright notice, this list of conditions and the following disclaimer.
+  Redistributions in binary form of the Software may reproduce the above
+  copyright notice, this list of conditions and the following disclaimer in
+  the documentation and/or other materials provided with the distribution.
+  Neither the name of Intel Corporation nor the names of its contributors
+  shall be used to endorse or promote products derived from this Software
+  without specific prior written permission.
+  
+  Intel hereby grants Recipient and Licensees a non-exclusive, worldwide,
+  royalty-free patent license under Licensed Patents to make, use, sell,
+  offer to sell, import and otherwise transfer the Software, if any, in
+  source code and object code form. This license shall include changes
+  to the Software that are error corrections or other minor changes
+  to the Software that do not add functionality or features when the
+  Software is incorporated in any version of a operating system that has
+  been distributed under the GNU General Public License 2.0 or later.
+  This patent license shall apply to the combination of the Software and
+  any operating system licensed under the GNU Public License version 2.0
+  or later if, at the time Intel provides the Software to Recipient, such
+  addition of the Software to the then publicly available versions of such
+  operating system available under the GNU Public License version 2.0 or
+  later (whether in gold, beta or alpha form) causes such combination to
+  be covered by the Licensed Patents. The patent license shall not apply
+  to any other combinations which include the Software. No hardware per
+  se is licensed hereunder.
+  
+  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
+  IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
+  THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+  PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL INTEL OR ITS CONTRIBUTORS
+  BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
+  OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+  SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+  INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+  CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+  THE POSSIBILITY OF SUCH DAMAGE.
 
-"Licensed Patents" means patent claims licensable by Intel Corporation which 
-are necessarily infringed by the use of sale of the Software alone or when 
-combined with the operating system referred to below.
-
-"Recipient" means the party to whom Intel delivers this Software.
-
-"Licensee" means Recipient and those third parties that receive a license to 
-any operating system available under the GNU Public License version 2.0 or 
-later.
-
-Copyright (c) 1999 - 2002 Intel Corporation.
-All rights reserved.
-
-The license is provided to Recipient and Recipient's Licensees under the 
-following terms.
-
-Redistribution and use in source and binary forms of the Software, with or 
-without modification, are permitted provided that the following conditions 
-are met:
-
-Redistributions of source code of the Software may retain the above 
-copyright notice, this list of conditions and the following disclaimer.
-
-Redistributions in binary form of the Software may reproduce the above 
-copyright notice, this list of conditions and the following disclaimer in 
-the documentation and/or materials provided with the distribution.
-
-Neither the name of Intel Corporation nor the names of its contributors 
-shall be used to endorse or promote products derived from this Software 
-without specific prior written permission.
-
-Intel hereby grants Recipient and Licensees a non-exclusive, worldwide, 
-royalty-free patent license under Licensed Patents to make, use, sell, offer 
-to sell, import and otherwise transfer the Software, if any, in source code 
-and object code form. This license shall include changes to the Software 
-that are error corrections or other minor changes to the Software that do 
-not add functionality or features when the Software is incorporated in any 
-version of an operating system that has been distributed under the GNU 
-General Public License 2.0 or later. This patent license shall apply to the 
-combination of the Software and any operating system licensed under the GNU 
-Public License version 2.0 or later if, at the time Intel provides the 
-Software to Recipient, such addition of the Software to the then publicly 
-available versions of such operating systems available under the GNU Public 
-License version 2.0 or later (whether in gold, beta or alpha form) causes 
-such combination to be covered by the Licensed Patents. The patent license 
-shall not apply to any other combinations which include the Software. NO 
-hardware per se is licensed hereunder.
-
-THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
-AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
-IMPLIED WARRANTIES OF MECHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
-ARE DISCLAIMED. IN NO EVENT SHALL INTEL OR IT CONTRIBUTORS BE LIABLE FOR ANY 
-DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES 
-(INCLUDING, BUT NOT LIMITED, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
-ANY LOSS OF USE; DATA, OR PROFITS; OR BUSINESS INTERUPTION) HOWEVER CAUSED 
-AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY OR 
-TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
-OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-**********************************************************************/
+*******************************************************************************/
 
 /**********************************************************************
 *                                                                     *
@@ -91,7 +86,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ans_os.h"
 #include <asm/unaligned.h>
 
-void (*ans_notify)(device_t *dev, int ind_type);
+void (*ans_notify)(device_t *dev, int ind_type) = NULL;
 
 BD_ANS_STATUS bd_ans_os_SetCallback(BOARD_PRIVATE_STRUCT *bps,
     IANS_BD_PARAM_HEADER *header)
@@ -307,6 +302,7 @@ bd_ans_os_Watchdog(device_t *dev, BOARD_PRIVATE_STRUCT *bps)
     }
     
     /* if we are here, we need to send a status change notification */
+    /// TBD - need to get indication definition from ans_base_comm.h 
     
     /* as far as I can tell, since it hasn't been defined yet,
      * the thing to do here is to call netdev_state_change(dev).
@@ -505,6 +501,10 @@ bd_ans_os_AttributeFill(iANS_Attribute_ID attr_id,
 void 
 bd_ans_os_ReserveSpaceForANS(struct sk_buff *skb)
 {
+  /// (??? what is the best way to
+  /// handle this variable number of tlv's? Perhaps ANS can set this 
+  /// number for us in a query or something, or as a define in the 
+  /// base_comm.h file...)
     skb_reserve(skb, BD_ANS_INFO_SIZE);
 }
        
