@@ -1,74 +1,69 @@
-/**********************************************************************
-This software program is available to you under a choice of one of two 
-licenses. You may choose to be licensed under either the GNU General Public 
-License (GPL) Version 2, June 1991, available at 
-http://www.fsf.org/copyleft/gpl.html, or the Intel BSD + Patent License, the 
-text of which follows:
+/*******************************************************************************
 
-Recipient has requested a license and Intel Corporation ("Intel") is willing
-to grant a license for the software entitled Linux Base Driver for the 
-Intel(R) PRO/100 Family of Adapters (e100) (the "Software") being provided 
-by Intel Corporation. The following definitions apply to this license:
+  Recipient has requested a license and Intel Corporation ("Intel") is
+  willing to grant a license for the software entitled Linux Base Driver
+  for the Intel(R) PRO/1000 Familty of Adapters (e1000) (the "Software")
+  being provided by Intel Corporation.
+  
+  The following definitions apply to this License:
+  
+  "Licensed Patents" means patent claims licensable by Intel Corporation
+  which are necessarily infringed by the use or sale of the Software alone
+  or when combined with the operating system referred to below.
+  "Recipient" means the party to whom Intel delivers this Software.
+  "Licensee" means Recipient and those third parties that receive a license
+  to any operating system available under the GNU Public License version
+  2.0 or later.
+  
+  Copyright (c) 1999-2001 Intel Corporation All rights reserved.
+  
+  The license is provided to Recipient and Recipient's Licensees under
+  the following terms.
+  
+  Redistribution and use in source and binary forms of the Software,
+  with or without modification, are permitted provided that the following
+  conditions are met:
+  
+  Redistributions of source code of the Software may retain the above
+  copyright notice, this list of conditions and the following disclaimer.
+  Redistributions in binary form of the Software may reproduce the above
+  copyright notice, this list of conditions and the following disclaimer in
+  the documentation and/or other materials provided with the distribution.
+  Neither the name of Intel Corporation nor the names of its contributors
+  shall be used to endorse or promote products derived from this Software
+  without specific prior written permission.
+  
+  Intel hereby grants Recipient and Licensees a non-exclusive, worldwide,
+  royalty-free patent license under Licensed Patents to make, use, sell,
+  offer to sell, import and otherwise transfer the Software, if any, in
+  source code and object code form. This license shall include changes
+  to the Software that are error corrections or other minor changes
+  to the Software that do not add functionality or features when the
+  Software is incorporated in any version of a operating system that has
+  been distributed under the GNU General Public License 2.0 or later.
+  This patent license shall apply to the combination of the Software and
+  any operating system licensed under the GNU Public License version 2.0
+  or later if, at the time Intel provides the Software to Recipient, such
+  addition of the Software to the then publicly available versions of such
+  operating system available under the GNU Public License version 2.0 or
+  later (whether in gold, beta or alpha form) causes such combination to
+  be covered by the Licensed Patents. The patent license shall not apply
+  to any other combinations which include the Software. No hardware per
+  se is licensed hereunder.
+  
+  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
+  IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
+  THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+  PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL INTEL OR ITS CONTRIBUTORS
+  BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
+  OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+  SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+  INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+  CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+  THE POSSIBILITY OF SUCH DAMAGE.
 
-"Licensed Patents" means patent claims licensable by Intel Corporation which 
-are necessarily infringed by the use of sale of the Software alone or when 
-combined with the operating system referred to below.
-
-"Recipient" means the party to whom Intel delivers this Software.
-
-"Licensee" means Recipient and those third parties that receive a license to 
-any operating system available under the GNU Public License version 2.0 or 
-later.
-
-Copyright (c) 1999 - 2002 Intel Corporation.
-All rights reserved.
-
-The license is provided to Recipient and Recipient's Licensees under the 
-following terms.
-
-Redistribution and use in source and binary forms of the Software, with or 
-without modification, are permitted provided that the following conditions 
-are met:
-
-Redistributions of source code of the Software may retain the above 
-copyright notice, this list of conditions and the following disclaimer.
-
-Redistributions in binary form of the Software may reproduce the above 
-copyright notice, this list of conditions and the following disclaimer in 
-the documentation and/or materials provided with the distribution.
-
-Neither the name of Intel Corporation nor the names of its contributors 
-shall be used to endorse or promote products derived from this Software 
-without specific prior written permission.
-
-Intel hereby grants Recipient and Licensees a non-exclusive, worldwide, 
-royalty-free patent license under Licensed Patents to make, use, sell, offer 
-to sell, import and otherwise transfer the Software, if any, in source code 
-and object code form. This license shall include changes to the Software 
-that are error corrections or other minor changes to the Software that do 
-not add functionality or features when the Software is incorporated in any 
-version of an operating system that has been distributed under the GNU 
-General Public License 2.0 or later. This patent license shall apply to the 
-combination of the Software and any operating system licensed under the GNU 
-Public License version 2.0 or later if, at the time Intel provides the 
-Software to Recipient, such addition of the Software to the then publicly 
-available versions of such operating systems available under the GNU Public 
-License version 2.0 or later (whether in gold, beta or alpha form) causes 
-such combination to be covered by the Licensed Patents. The patent license 
-shall not apply to any other combinations which include the Software. NO 
-hardware per se is licensed hereunder.
-
-THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
-AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
-IMPLIED WARRANTIES OF MECHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
-ARE DISCLAIMED. IN NO EVENT SHALL INTEL OR IT CONTRIBUTORS BE LIABLE FOR ANY 
-DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES 
-(INCLUDING, BUT NOT LIMITED, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
-ANY LOSS OF USE; DATA, OR PROFITS; OR BUSINESS INTERUPTION) HOWEVER CAUSED 
-AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY OR 
-TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
-OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-**********************************************************************/
+*******************************************************************************/
 
 /**********************************************************************
 *                                                                     *
@@ -92,9 +87,9 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include <linux/sockios.h> /* for SIOCDEVPRIVATE */
 
-#define UINT16 __u16
-#define UINT32 __u32
-#define UCHAR  __u8
+#define u16 __u16
+#define u32 __u32
+#define u8  __u8
 
 
 /* Make sure all communications parties use the same packing mode
@@ -131,12 +126,12 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *------------------------------------------------------------------*/
 
 /* iANS's communications version */
-#define IANS_COMM_VERSION_MAJOR (UINT16)1
-#define IANS_COMM_VERSION_MINOR (UINT16)0
+#define IANS_COMM_VERSION_MAJOR (u16)1
+#define IANS_COMM_VERSION_MINOR (u16)0
 
 /* Base driver's version */ 
-#define IANS_BD_COMM_VERSION_MAJOR (UINT16)1
-#define IANS_BD_COMM_VERSION_MINOR (UINT16)0
+#define IANS_BD_COMM_VERSION_MAJOR (u16)1
+#define IANS_BD_COMM_VERSION_MINOR (u16)0
 
 #define IANS_SIGNATURE_LENGTH 80
 
@@ -324,7 +319,7 @@ typedef enum _IANS_BD_REQUEST_SUPPORT {
 typedef struct _IANS_BD_PARAM_HEADER
 {
     // Cast from IANS_BASE_OPCODE to insure forward size compatibility 
-    /* UINT32 */ int    Opcode; 
+    /* u32 */ int    Opcode; 
 } IANS_BD_PARAM_HEADER, *PIANS_BD_PARAM_HEADER;
 
 
@@ -340,16 +335,16 @@ typedef struct _IANS_BD_PARAM_HEADER
 
 typedef struct _IANS_BD_PARAM_STATUS
 {  
-    UINT32     StatusVersion;       /* The version of this struct */
+    u32     StatusVersion;       /* The version of this struct */
     
-    UINT32     LinkStatus;          /* Cast from IANS_BD_LINK_STATUS */
-    UINT32     LinkSpeed;           /* Cast from IANS_BD_LINK_SPEED */
-    UINT32     Duplex;              /* Cast from IANS_BD_DUPLEX_STATUS  */
-    UINT32     HardwareFailure;     /* Cast from IANS_BD_HW_FAILURE */
-    UINT32     DuringResetProcess;  /* Cast from IANS_BD_RESET_STAGE  */
-    UINT32     Suspended;           /* Cast from IANS_BD_SUSPENDED_STAGE  */
+    u32     LinkStatus;          /* Cast from IANS_BD_LINK_STATUS */
+    u32     LinkSpeed;           /* Cast from IANS_BD_LINK_SPEED */
+    u32     Duplex;              /* Cast from IANS_BD_DUPLEX_STATUS  */
+    u32     HardwareFailure;     /* Cast from IANS_BD_HW_FAILURE */
+    u32     DuringResetProcess;  /* Cast from IANS_BD_RESET_STAGE  */
+    u32     Suspended;           /* Cast from IANS_BD_SUSPENDED_STAGE  */
 
-    UINT32     HotPlug;    /* Cast from IANS_BD_HOT_PLUG_STATUS  */
+    u32     HotPlug;    /* Cast from IANS_BD_HOT_PLUG_STATUS  */
 } IANS_BD_PARAM_STATUS, *PIANS_BD_PARAM_STATUS;
 
 /*--------------------------------------------------------------------*
@@ -380,14 +375,14 @@ typedef struct _IANS_BD_PARAM_IDENTIFY
 {
     IANS_BD_PARAM_HEADER           Header;                 /* Common to all commands */
 
-    UCHAR      iANSSignature[IANS_SIGNATURE_LENGTH]; 
+    u8      iANSSignature[IANS_SIGNATURE_LENGTH]; 
     /* iANS fills copyright string*/
-    UCHAR      BDSignature[IANS_SIGNATURE_LENGTH];   
+    u8      BDSignature[IANS_SIGNATURE_LENGTH];   
     /* BD fills copyright string*/
-    UINT32     iANSCommVersion;  /* iANS supported comm. version */
+    u32     iANSCommVersion;  /* iANS supported comm. version */
     /* Upper word = major version number */
     /* lower word = minor version number */
-    UINT32     BDCommVersion;    /* Base driver supported comm. version */
+    u32     BDCommVersion;    /* Base driver supported comm. version */
 } IANS_BD_PARAM_IDENTIFY, *PIANS_BD_PARAM_IDENTIFY;
 
 
@@ -412,16 +407,16 @@ typedef struct _IANS_BD_PARAM_EXT_CAP
 {
     IANS_BD_PARAM_HEADER           Header;                 /* Common to all commands */
 
-    UINT32 BDCanSetMacAddress;    /* MAC Address setting - cast from 
+    u32 BDCanSetMacAddress;    /* MAC Address setting - cast from 
                                      IANS_BD_SUPPORT*/
-    UINT32 BDIansStatusVersion;    /* Status indication with iANS struct 
+    u32 BDIansStatusVersion;    /* Status indication with iANS struct 
                                       - which version is supported  */
-    UINT32 BDAllAvailableRouting;               /* Bitmask of all available Rx/Event
+    u32 BDAllAvailableRouting;               /* Bitmask of all available Rx/Event
                                                  * routings. IANS_BD_ROUTING */
 
-    UINT32     BDFlags;    /* The adapter's flags */
+    u32     BDFlags;    /* The adapter's flags */
 
-    UINT32     BDAllAvailableSpeeds; /* A bit mask of all available speeds */
+    u32     BDAllAvailableSpeeds; /* A bit mask of all available speeds */
 
 } IANS_BD_PARAM_EXT_CAP, *PIANS_BD_PARAM_EXT_CAP;
 
@@ -441,15 +436,15 @@ typedef struct _IANS_BD_PARAM_EXT_SET_MODE
 {
     IANS_BD_PARAM_HEADER           Header; /* Common to all commands */
 
-    UINT32 BDIansStatusReport;   /* Ask the base driver to report status through 
+    u32 BDIansStatusReport;   /* Ask the base driver to report status through 
                                   * status struct.  
                                   * Cast from IANS_BD_REQUEST. */
 
-    UINT32 BDIansAttributedMode; /* Ask the base driver to send and receive
+    u32 BDIansAttributedMode; /* Ask the base driver to send and receive
                                   * packets accompanied by a per-frame data structure
                                   * Cast from IANS_BD_REQUEST. */
 
-    UINT32 BDIansRoutingMode;    /* Bitmask of one Rx and one IANS_BD_ROUTING */
+    u32 BDIansRoutingMode;    /* Bitmask of one Rx and one IANS_BD_ROUTING */
 
 
 } IANS_BD_PARAM_EXT_SET_MODE, *PIANS_BD_PARAM_EXT_SET_MODE;
@@ -469,8 +464,8 @@ typedef struct _IANS_BD_PARAM_ITAG_CAP
 {
     IANS_BD_PARAM_HEADER           Header;                 /* Common to all commands */
 
-    UINT32                 ISLTagMode;         /* cast from IANS_BD_SUPPORT */
-    UINT32                 IEEE802_3acTagMode; /* cast from IANS_BD_SUPPORT */
+    u32                 ISLTagMode;         /* cast from IANS_BD_SUPPORT */
+    u32                 IEEE802_3acTagMode; /* cast from IANS_BD_SUPPORT */
 
 } IANS_BD_PARAM_ITAG_CAP, *PIANS_BD_PARAM_ITAG_CAP;
 
@@ -485,7 +480,6 @@ typedef enum _IANS_BD_TAGGING_MODE
 {
     IANS_BD_TAGGING_NONE =0,
     IANS_BD_TAGGING_802_3AC,
-    IANS_BD_TAGGING_ISL,
     IANS_BD_TAGGING_UNDEFINED
 }IANS_BD_TAGGING_MODE , *PIANS_BD_TAGGING_MODE ;
 
@@ -493,7 +487,7 @@ typedef struct _IANS_BD_PARAM_ITAG_SET_MODE
 {
     IANS_BD_PARAM_HEADER           Header;              /* Common to all commands */
 
-    UINT32                SetTagMode;  /* cast from IANS_BD_TAGGING_MODE  */
+    u32                SetTagMode;  /* cast from IANS_BD_TAGGING_MODE  */
 } IANS_BD_PARAM_ITAG_SET_MODE, *PIANS_BD_PARAM_ITAG_SET_MODE;
 
 #endif /* IANS_BASE_VLAN_TAGGING */
@@ -512,10 +506,10 @@ typedef struct _IANS_BD_PARAM_IVLAN_CAP
 {
     IANS_BD_PARAM_HEADER           Header;                 /* Common to all commands */
 
-    UINT32           VlanIDCapable;          /* Cast from IANS_BD_SUPPORT */
-    UINT32           VlanIDFilteringAble;    /* Cast from IANS_BD_SUPPORT */
-    UINT16           MaxVlanIDSupported;     /* Max. VLan ID supported by BD */
-    UINT32           MaxVlanTableSize;       /* Max. number of VLan IDs in a table */
+    u32           VlanIDCapable;          /* Cast from IANS_BD_SUPPORT */
+    u32           VlanIDFilteringAble;    /* Cast from IANS_BD_SUPPORT */
+    u16           MaxVlanIDSupported;     /* Max. VLan ID supported by BD */
+    u32           MaxVlanTableSize;       /* Max. number of VLan IDs in a table */
 } IANS_BD_PARAM_IVLAN_CAP, *PIANS_BD_PARAM_IVLAN_CAP;
 
 /*--------------------------------------------------------------------*
@@ -528,8 +522,8 @@ typedef struct _IANS_BD_PARAM_IVLAN_CAP
 typedef struct _IANS_BD_PARAM_IVLAN_SET_MODE
 {
     IANS_BD_PARAM_HEADER           Header;                    /* Common to all commands */
-    UINT32           VlanIDRequest;           /* Cast from IANS_BD_REQUEST */
-    UINT32           VlanIDFilteringRequest;  /* Cast from IANS_BD_REQUEST */
+    u32           VlanIDRequest;           /* Cast from IANS_BD_REQUEST */
+    u32           VlanIDFilteringRequest;  /* Cast from IANS_BD_REQUEST */
 } IANS_BD_PARAM_IVLAN_SET_MODE, *PIANS_BD_PARAM_IVLAN_SET_MODE;
 
 /*--------------------------------------------------------------------*
@@ -542,9 +536,9 @@ typedef struct _IANS_BD_PARAM_IVLAN_TABLE
 {
     IANS_BD_PARAM_HEADER           Header;         /* Common to all commands */
 
-    UINT32        VLanIDNum;       /* Number of VLan IDs defined in 
+    u32        VLanIDNum;       /* Number of VLan IDs defined in 
                                       this table */
-    UINT16        *VLanIDTable;  /* Beginning of ID list. 
+    u16        *VLanIDTable;  /* Beginning of ID list. 
                                     * iANS will allocate enough space 
                                     * for the whole table, and it will 
                                     * start from this field - we don't 
@@ -566,9 +560,9 @@ typedef struct _IANS_BD_PARAM_IVLAN_TABLE
 
 typedef struct _Per_Frame_Attribute_Header
 {
-    UINT32               AttributeID;   /* Indicates which kind of data is contained
+    u32               AttributeID;   /* Indicates which kind of data is contained
                                            in this field */
-    UINT32               AttributeLength; /* Length of this attribute */
+    u32               AttributeLength; /* Length of this attribute */
 } Per_Frame_Attribute_Header, *pPer_Frame_Attribute_Header;
 
 
@@ -581,7 +575,7 @@ typedef struct _Per_Frame_Attribute_Header
 typedef struct _IANS_ATTR_HEADER
 {
     pPer_Frame_Attribute_Header         pFirstTLV;              /* NULL if not attributed */
-    UINT32                                      OriginalProtocol;
+    u32                                      OriginalProtocol;
 } IANS_ATTR_HEADER, *PIANS_ATTR_HEADER;
 
 /* Turn into a legal pointer */
@@ -640,8 +634,8 @@ typedef struct _VLAN_ID_Per_Frame_Info
 {
     Per_Frame_Attribute_Header  AttrHeader;
 
-    UINT16 VLanID;
-    UCHAR  Padding[2];
+    u16 VLanID;
+    u8  Padding[2];
 
 } VLAN_ID_Per_Frame_Info  , *pVLAN_ID_Per_Frame_Info ;
 
